Brightness

Struct Brightness 

pub struct Brightness(pub u16);
Wrapper around the headset’s internal brightness value.

Internally, brightness values are handled as an integer between 6 and 542, mapping onto the -20 to 150 values seen in the official utility. This provides a safe wrapper to ensure incorrect values don’t get passed around.

Tuple Fields

0: u16

Implementations

Source

impl Brightness

pub fn try_from_utilfmt(value: f32) -> Result<Self, ()>

Lossy attempt to convert from a user-friendly value, to the internal quantized representation.

Errors

If the inputted value is outside the accepted range for conversion. Must be between approx -23.15 and approx 1_988_000_000.

pub fn to_utilfmt(self) -> f32

Converts to a user-friendly.