CommandIds

Enum CommandIds 

#[non_exhaustive]
#[repr(u8)]
pub enum CommandIds {
Show 16 variants Ack = 36, Error = 69, SecondarySerial = 38, FirmwareVersion = 42, TimeStat = 90, SetFan = 70, SetBrightness = 73, SetLed = 76, SetMode = 100, Log = 59, DeviceStat = 35, ReadMemory = 85, WriteMemory = 87, CommitMemory = 86, FirmwareFlash = 66, BigeyeCommand = 101,
}
A list of all commands that can be sent or received from the mainboard.

These commands are only for the regular mode of the mainboard.

Implementation

The data sent to, or received by the HMD must always be HID_REPORT_SIZE bytes large, with the first byte representing the command ID. The subsequent [HID_REPORT_SIZE - 1] bytes can be used for any extra data required for this command.

If a sent command does not need to return anything, Self::Ack will be returned by default.

If a command fails, Self::Error will be returned to indicate something going wrong.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Ack = 36

Returned when a command is sent that doesn’t need a response.

Some examples of when it’ll return are:

  • Setting the fan speed.
  • Setting the brightness.
  • Writing memory.


Error = 69

Returned when a command fails for whatever reason.



SecondarySerial = 38

When sent, headset will respond with a null-terminated string of the secondary serial number.



FirmwareVersion = 42

When sent, headset will respond with a null-terminated string of the firmware version.



TimeStat = 90

Send, in addition to a second byte representing which time statistic you want to obtain from the headset.

The available statistics are:

  • 0: Idle time
  • 1: Usage time
  • 2: Longest session

The returned value is a little-endian u32 in deca-minutes (10 minutes), meaning you will need to multiply by TIMESTAT_STEP to get the value in minutes.

Data representation

The returned value is alright to store in a u32 due to the maximum value (u32::MAX) taking approx 82,000 years to overflow.



SetFan = 70

Send, in addition to a byte representing the fan speed from 0 to 100, to temporarily set the fan speed.



SetBrightness = 73

Send, in addition to a big-endian u16 representing the brightness, to temporarily set the current brightness.

Also see: crate::helpers::Brightness.



SetLed = 76

Send, in addition to 3 bytes representing red, green, and blue (in this order) to set the LED color.

Also see: crate::helpers::RgbColor.



SetMode = 100

Send, in addition to a byte representing which display mode (refresh rate & resolution) to use.

Values for this extra byte can be:

  • 0: 2560x2560 @ 75 Hz
  • 1: 1920x1920 @ 90 Hz

Also see: crate::helpers::DisplayMode.



Log = 59



DeviceStat = 35



ReadMemory = 85

Send, in addition to a byte representing the bank (zero indexed, crate::protocol::memory::BANK_COUNT banks total), to get a byte of size (always crate::protocol::memory::BANK_CAPACITY), followed by size bytes of data.

To get the full memory (crate::protocol::memory::MEMORY_SIZE bytes large), concat all the banks.

Decoding

To decode the banks, see crate::protocol::memory::ConfigurationMemory for details on how to do this.

Also see: crate::protocol::memory.



WriteMemory = 87

Send, in addition to a byte representing the bank (zero indexed, crate::protocol::memory::BANK_COUNT banks total), and crate::protocol::memory::BANK_CAPACITY bytes of data (for crate::protocol::memory::MEMORY_SIZE bytes of total data).

Once complete, Self::CommitMemory must be sent.

Also see: crate::protocol::memory.



CommitMemory = 86

Send to commit memory written by Self::WriteMemory.

If the display mode in the memory has been changed (see crate::protocol::memory::MemoryItem::DisplayMode), an extra ack (Self::Ack) will be returned.



FirmwareFlash = 66



BigeyeCommand = 101

Implementations

Source

impl CommandIds

pub const fn from_repr(discriminant: u8) -> Option<CommandIds>

Try to create Self from the raw representation

Source

impl CommandIds

pub const fn id(self) -> u8