BSBDevice

Struct BSBDevice 

pub struct BSBDevice { /* private fields */ }
Main handler for the Bigscreen Beyond device.

Examples

After initializing, you can use the various included functions to change the state of the Bigscreen Beyond device.

let dev = BSBDevice::new()?;

dev.set_fan_speed(50)?;

A lot of the time, you’ll need to permanently modify the memory. Here’s an example on how to do that:

let dev = BSBDevice::new()?;

let mut memory = dev.read_memory()?;
memory.set_fan(50);
dev.write_memory(&memory)?;

Implementations

Source

impl BSBDevice

pub fn new() -> Result<Self, DeviceError>

pub fn get_hid_manufacturer(&self) -> Result<Option<String>, DeviceError>

Fetches the manufacturer string through the underlying HID event.

pub fn get_hid_product(&self) -> Result<Option<String>, DeviceError>

Fetches the product string through the underlying HID event.

pub fn get_hid_serial(&self) -> Result<Option<String>, DeviceError>

Fetches the serial number string through the underlying HID event.

Note that this is the “primary serial”, and is normally hidden to the user. If you are looking for the serial, check out Self::get_secondary_serial, which gets the “secondary serial” starting with “BS”.

pub fn get_secondary_serial(&self) -> Result<String, DeviceError>

Fetches the “secondary serial”.

This is the value shown on the utility, and starts with “BS”.

pub fn get_firmware_version(&self) -> Result<String, DeviceError>

Fetches the active firmware version.

pub fn set_fan_speed(&self, v: u8) -> Result<(), DeviceError>

Temporarily activates the fan, setting its speed.

pub fn set_brightness(&self, v: &Brightness) -> Result<(), DeviceError>

Temporarily modifies the current brightness.

pub fn set_led_color(&self, v: &RgbColor) -> Result<(), DeviceError>

Temporarily modifies the LED color.

pub fn set_display_mode(&self, v: &DisplayMode) -> Result<(), DeviceError>

Modifies & saves the display mode.

pub fn get_time_idle(&self) -> Result<u32, DeviceError>

Total time the HMD has had power, but no usage.

Returns in minutes, to the closest TIMESTAT_STEP.

pub fn get_time_usage(&self) -> Result<u32, DeviceError>

Total usage time.

Returns in minutes, to the closest TIMESTAT_STEP.

pub fn get_time_longest(&self) -> Result<u32, DeviceError>

Time in the longest session, where a session is the continuous activation of the proximity sensor.

Returns in minutes, to the closest TIMESTAT_STEP.

pub fn read_memory(&self) -> Result<ConfigurationMemory, DeviceError>

Reads the static configuration memory.

pub fn write_memory( &self, data: &ConfigurationMemory, ) -> Result<(), DeviceError>

Writes to the static configuration memory.

This persists when the headset looses power.

pub fn get_status(&self) -> Result<DeviceStatus, DeviceError>